#!/usr/bin/env python
#
# CanDo - Web based competency tracking system.
# Copyright (C) 2006 Arlington Public Schools, Arlington, VA and The
# Shuttleworth Foundation.
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software Foundation,
# Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
#
"""
CanDo setup script.
"""
import os
from setuptools import setup, find_packages

if os.path.exists("version.txt"):
    version = open("version.txt").read().strip()
else:
    version = open("version.txt.in").read().strip()

# Setup CanDo
setup(
    name="cando",
    description="A competency tracking system built on SchoolTool.",
    long_description="""
CanDo is an online application that allows teachers and administrators
to track student acquisition of competencies during a course. Using a
database of competencies which students are expected to acquire,
teachers can use CanDo to track and manage student progress in meeting
their competency goals. In order to demonstrate competency
acquisition, students are invited to submit proof entries in their
CanDo web portfolios. Students go through the competency profile to
create links between each competency acquired and the proof entries
associated with each competency. Teachers will then have the
possibility of accepting, rejecting or commenting upon the proofs of
competency acquisition submitted by the students.""",
    version=version,
    url='http://cando.schooltool.org',
    license="GPL",
    maintainer="Jason Straw",
    maintainer_email="jstraw@candoskills.org",
    platforms=["any"],
    classifiers=["Development Status :: 4 - Beta",
    "Environment :: Web Environment",
    "Intended Audience :: End Users/Desktop",
    "License :: OSI Approved :: GNU General Public License (GPL)",
    "Operating System :: OS Independent",
    "Programming Language :: Python",
    "Programming Language :: Zope",
    "Topic :: Education",
    "Topic :: Office/Business :: Scheduling"],
    package_dir={'': 'src'},
    packages=find_packages('src'),
    install_requires=['zc.resourcelibrary',
                      'zc.datetimewidget',
                      'zope.i18nmessageid >= 3.4.2',
                      'zope.viewlet',
                      'zope.app.onlinehelp',
                      'zope.app.apidoc',
                      'zope.app.locales',
                      'z3c.zrtresource',
                      'z3c.layer',
                      'z3c.menu',
                      'z3c.optionstorage',
                      'z3c.pagelet',
                      'z3c.template',
                      'z3c.form',
                      'z3c.formjs >= 0.4.1',
                      'zope.app.generations',
                      'zope.app.zcmlfiles',
                      'schooltool',
                      'schooltool.gradebook',
                      'PasteDeploy',
                      'PasteScript'],
    dependency_links=['http://ftp.schooltool.org/schooltool/1.0'],
    entry_points = """
    [schooltool.instance_type]
    cando2007 = cando.cando2007
    """,
    include_package_data=True
    )
