#
# CanDo - Web based competency tracking system.
# Copyright (C) 2006 Arlington Public Schools, Arlington, VA and The
# Shuttleworth Foundation.
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software Foundation,
# Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
#
from zope.app import zapi
from zope.component import queryUtility
from zope.formlib import form
from zope.interface import Interface
from zope.schema import Password
from z3c.pagelet.browser import BrowserPagelet

from schooltool.common import SchoolToolMessage as _
from schooltool.app.interfaces import ISchoolToolApplication
from schooltool.person.interfaces import IPerson, IPasswordWriter
from schooltool.skin.form import BasicForm
from schooltool.term.interfaces import IDateManager
from schooltool.widget.password import PasswordConfirmationWidget

from cando.newskin import PersonDistinguisher


class Go(BrowserPagelet, PersonDistinguisher):
    def update(self):
        term = queryUtility(IDateManager).current_term
        self.sectionsURL = zapi.absoluteURL(term, self.request) + "/sections/go.html"
        self.no_crumb_options = True
        if not self.isTeacher and not self.isStudent:
            app = ISchoolToolApplication(None)
            nexturl = zapi.absoluteURL(app, self.request) + "/competencies"
            self.request.response.redirect(nexturl)


class LoginDispatchView(BrowserPagelet, PersonDistinguisher):
    def __call__(self):
        app = ISchoolToolApplication(None)
        nexturl = zapi.absoluteURL(app, self.request) + "/go.html"
        if self.isManager:
            nexturl = zapi.absoluteURL(app, self.request) + "/manage.html"
        self.request.response.redirect(nexturl)


class IPasswordEditForm(Interface):
    """Schema for a person's edit form."""

    password = Password(
        title=_("Password"),
        required=False)


class PersonPasswordEditView(BasicForm):
    form_fields = form.Fields(IPasswordEditForm, render_context=False)
    form_fields['password'].custom_widget = PasswordConfirmationWidget

    def title(self):
        return _("Edit password")

    @form.action(_("Apply"))
    def handle_edit_action(self, action, data):
        if not data['password']:
            self.status = _("No new password was supplied so "
                            "original password is unchanged")
            return
        writer = IPasswordWriter(IPerson(self.request.principal))
        writer.setPassword(data['password'])
        url = zapi.absoluteURL(ISchoolToolApplication(None), self.request)
        self.request.response.redirect(url)

    @form.action(_("Cancel"))
    def handle_cancel_action(self, action, data):
        # redirect to parent
        url = zapi.absoluteURL(ISchoolToolApplication(None), self.request)
        self.request.response.redirect(url)
        return ''

