#
# CanDo - Web based competency tracking system.
# Copyright (C) 2006 Arlington Public Schools, Arlington, VA and The
# Shuttleworth Foundation.
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software Foundation,
# Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
#
"""Queuing Interfaces

$Id$
"""
__docformat__='restructuredtext'


from zope import schema
from zope.interface import Interface, Attribute

from schooltool.course.interfaces import ISection

from cando.message.interfaces import IMessage


class IQueueItem(Interface):
    """A queue item"""

    context = schema.Object(
        schema=IMessage,
        title=u"Message",
        description=u"Queued Message",
        required=True)

    section = schema.TextLine(
        title=u"Section",
        description=u"Identifier of the associated Section",
        required=False)

    person = schema.TextLine(
        title=u"Person",
        description=u"Identifier of the associated Person",
        required=False)

    history = schema.List(
        title=u"History",
        description=u"Queue Item History",
        value_type=schema.List(title=u"Status"),
        required=False)

    status = Attribute("""Status of a queue item""")


class IQueue(Interface):
    """A queue"""

    context = schema.Object(
        schema=ISection,
        title=u"Section",
        description=u"Section",
        required=True)

    items = schema.List(
        title=u"Items",
        description=u"Queued items in the queue",
        required=False)

class IQueueable(Interface):
    """Marker interface for objects that are queuable, namely Messages"""


class IHaveQueue(Interface):
    """Marker interface for objects that have a queue, namely Sections"""
