#
# CanDo - Web based competency tracking system.
# Copyright (C) 2006 Arlington Public Schools, Arlington, VA and The
# Shuttleworth Foundation.
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software Foundation,
# Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
#
from zope.security.proxy import removeSecurityProxy
from cando.virginia.scoresystem import VirginiaCompetencyScoreSystem
from cando.virginia.interfaces import ICompetencies
from cando.skilldriver import interfaces


class IndexFormView(object):

    def getSkillCompetencies(self):
	return self.skillCompetencies(self.selectedDriver())

    def selectedDriver(self):
	for item in self.request.form.values():
	    for driver in self.getSkillDriver():
		if item == driver.title:
		    return driver

    def getSkillDriver(self):
	"""Returns list of all skillDriver objects within self.context."""

	drivers = []
	section = removeSecurityProxy(self.context)
	for course in section.courses:
            skilldrivers = interfaces.ISkillDrivers(course)
            for skilldriver in skilldrivers.values():
		drivers.append(skilldriver)
	return drivers

    def getStudents(self):
	"""Returns list of all IPerson instances in section."""

	return removeSecurityProxy(self.context).members

    def skillCompetencies(self, *skilldriver):
	"""Returns all competencies within section's SkillDriver instances."""
	if not skilldriver:
	    skilldriver = self.getSkillDriver()	

	competencies = []
	for driver in skilldriver:
	    for comp in driver.competencies:
		if comp not in competencies:
		    competencies.append(comp)
	return competencies

    def allCompetencies(self, *courses):
	"""Return all IVirginiaCompetencies within list of courses,
	    default is all courses."""

	competencies = []
	if not courses:
	    courses = self.context.courses
	for course in courses:
	    comp = ICompetencies(course)
	    for node in self.recurTree(comp):
		if ICompetencies.implementedBy(node) == True:
		    competencies.append(node)
        return competencies

    def recurTree(self, node, n=0):
	"""Yields every competency object in competency tree."""

	yield {'node': node, 'depth': n}
        for subnode in node.values():
            for result in self.recurTree(subnode, n+1):
                yield result['node']

    def getScoring(self):
	"""Returns list of scoring options."""

	scoreOptions = []
	for item in VirginiaCompetencyScoreSystem.scores:
	    scoreOptions.append(item[1])
	return scoreOptions
