#
# CanDo - Web based competency tracking system.
# Copyright (C) 2006 Arlington Public Schools, Arlington, VA and The
# Shuttleworth Foundation.
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software Foundation,
# Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
#
"""
Competency stuff sample data generation

$Id: sampledata.py $
"""
import random

from zope.component import queryUtility
from zope.interface import implements
from zope import schema
from zope.formlib import form
from zope.security import proxy

from schooltool.course.interfaces import ISectionContainer
from schooltool.sampledata.interfaces import ISampleDataPlugin
from schooltool.term.interfaces import IDateManager

from cando.virginia.competency import Competencies
from cando.virginia.interfaces import ICompetencies, ICompetencyReference
from cando.gradebook.interfaces import ICompetencyGradebook
from cando.virginia.scoresystem import UniversalScore
from zope.i18nmessageid import MessageFactory

_ = MessageFactory('cando')

class ISampleCompetencyAssignment(ISampleDataPlugin):
    """Marker interface."""

class SampleCompetencyAssignment(object):

    implements(ISampleCompetencyAssignment)

    name = _('Competency Assignment')
    dependencies = ()

    def setUpScoreSystem(self, app):
        ss = proxy.removeSecurityProxy(app['scoresystem'])
        ss.addScore(UniversalScore(u"One", 1, 1.))
        ss.addScore(UniversalScore(u"Two", 2, 1.))
        ss.addScore(UniversalScore(u"Three", 3, 1.))
        ss.addScore(UniversalScore(u"Four", 4, 1.))
        ss.addScore(UniversalScore(u"Five", 5, 1.))
        ss.minPassingScore = ss.fromUnicode(u"4")
        return ss

    def generateGlobalComps(self, globalCompetencies):

        # XXX: BROKEN AS HELL AND DOES NOT WORK ANYMORE.

        # create Progamming division and add it to global comps
        programming = Competencies(u'Programming')
        globalCompetencies[u'Programming'] = programming

        # create Basic Progamming course comps
        basicProgramming = Competencies(u'Basic Programming')
        programming['Basic Programming'] = basicProgramming
        variables = Competencies(u'Working with Variables')
        basicProgramming[u'variables'] = variables
        variables[u'assignment'] = VirginiaCompetency(u'Assign a value to a variable.', u'001')
        loops = Competencies(u'Working with Loops')
        basicProgramming[u'loops'] = loops
        loops[u'forloop'] = VirginiaCompetency(u'Write a for loop.', u'002')

        # create Advanced Progamming course comps
        advancedProgramming = Competencies(u'Advanced Programming')
        programming['Advanced Programming'] = advancedProgramming
        classes = Competencies(u'Working with Classes')
        advancedProgramming[u'classes'] = classes
        classes[u'creation'] = VirginiaCompetency(u'Create a class definition.', u'001')
        generators = Competencies(u'Working with Generators')
        advancedProgramming[u'generators'] = generators
        generators[u'creation'] = VirginiaCompetency(u'Write a generator.', u'002')

    def generate(self, app, seed=None):
        app = proxy.removeSecurityProxy(app)
        scoreSystem = self.setUpScoreSystem(app)
        globalCompetencies = proxy.removeSecurityProxy(ICompetencies(app))
        if not len(globalCompetencies.values()):
            self.generateGlobalComps(globalCompetencies)
        courseComps = []
        for division in globalCompetencies.values():
            courseComps += list(division.values())
        for course in app['courses'].values():
            courseComp = proxy.removeSecurityProxy(ICompetencies(course))
            if not courseComp.bases:
                courseComp.addBase(random.choice(courseComps))

class SampleCompetencyAssignmentView(object):
    """ """

    def __call__(self):
        return """This script is meant to work with the Verso Import script.
                  It takes all the competencies two levels deep from the
                  global competencies and randomly distributes them among all
                  the courses in the system."""


class ISampleCompetencyGrading(ISampleDataPlugin):
    """Sample Competency Grading"""

    maxGrades = schema.Int(
        title=u"Maximum Count",
        description=u"""The maximum number of evaluations to create.  For
                        computers with less memory, less than 100,000 is
                        recommended.  If left blank, all possible evaluations
                        will be made.  (More than 500,000 with schooltool test
                        data)""",
        required=False)

    overwrite = schema.Bool(
        title=u"Overwrite Existing Evaluations",
        description=u"""If turned on, then competencies for which a student
                        already has an evaluation will not be skipped.""",
        required=True)


class SampleCompetencyGrading(object):

    implements(ISampleCompetencyGrading)

    name = _('Competency Evaluation')
    dependencies = ()
    maxGrades = -1
    overwrite = True

    def getFlatCompetencies(self, rootComp):
        """This builds a flat list of a competency tree.

        It includes the competency that is the root from which the tree starts
        and all of it's childrens' childrens' ... children.
        """
        competencies = [rootComp]
        for comp in rootComp.values():
            competencies += self.getFlatCompetencies(comp)
        return competencies

    def generate(self, app, seed=None):
        app = proxy.removeSecurityProxy(app)
        count = 0
        sectionCount = 0
        studentCount = 0
        scoreSystem = app['scoresystem']
        term = queryUtility(IDateManager).current_term
        for section in ISectionContainer(term).values():
            gradebook = ICompetencyGradebook(section)
            for student in gradebook.students:
                competencies = self.getFlatCompetencies(gradebook.competencies)
                for comp in competencies:
                    if not ICompetencyReference.providedBy(comp):
                        continue
                    score = random.choice(scoreSystem.scores)
                    gradebook.evaluate(student, comp, score)
                    count += 1
                    if count % 1000 == 0:
                        print _("graded %s comps, %s students, %s sections" % (count, studentCount, sectionCount))
                    if self.maxGrades != -1 and count > self.maxGrades:
                        return
                studentCount += 1
            sectionCount += 1


class SampleCompetencyGradingView(form.SubPageEditForm):
    """Form for grading competencies."""

    prefix = 'compGrade'
    form_fields = form.Fields(ISampleCompetencyGrading)
    actions = ()
