#
# CanDo - Web based competency tracking system.
# Copyright (C) 2006 Arlington Public Schools, Arlington, VA and The
# Shuttleworth Foundation.
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software Foundation,
# Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
#
"""Virginia Competency Implementation

$Id: student.py 1611 2009-08-19 18:12:29Z replaceafill $
"""


import zope.interface
from zope.app.container.btree import BTreeContainer
from schooltool.common import SchoolToolMessage as _
from schooltool.basicperson.interfaces import IBasicPerson
from schooltool.app.app import getSchoolToolApplication
from schooltool.app.app import InitBase
from schooltool.basicperson.interfaces import IDemographicsFields
from schooltool.basicperson.demographics import TextFieldDescription
from schooltool.basicperson.demographics import EnumFieldDescription
from cando.virginia.competency import interfaces


STUDENT_DEMOGRAPHICS_KEY = "cando.virginia.student_demographics"
DEMOGRAPHICS_FIELDS_KEY = 'schooltool.basicperson.demographics_fields'


_ethnicity_codes = {
    'a': _('Asian'),
    'b': _('Black'),
    'h': _('Hispanic'),
    'i': _('American Indian'),
    'u': _('Unspecified'),
    'w': _('White'),
    }


# XXX: Not used anymore. Use SchoolTool demographics instead
class StudentDemographics(object):
    zope.interface.implements(interfaces.IStudentDemographics)
    zope.component.adapts(IBasicPerson)

    def __init__(self, person):
        self.person_id = person.__name__

    @property
    def _demographics(self):
        app = getSchoolToolApplication()
        if STUDENT_DEMOGRAPHICS_KEY not in app:
            app[STUDENT_DEMOGRAPHICS_KEY] = BTreeContainer()
        container = app[STUDENT_DEMOGRAPHICS_KEY]
        if self.person_id not in container:
            container[self.person_id] = BTreeContainer()
        return container[self.person_id]

    def _setval(self, name, val):
        """Helper to set a value in demographics container."""
        container = self._demographics
        if name in container:
            del container[name]
        container[name] = val

    def _getEthnicCode(self):
        return self._demographics.get('ethnic_code', u'u')

    def _setEthnicCode(self, code):
        if code is not None:
            code = unicode(code).lower()
        self._setval('ethnic_code', code)

    ethnic_code = property(_getEthnicCode, _setEthnicCode)

    @property
    def ethnicity(self):
        return _ethnicity_codes.get(self.ethnic_code, u'')

    def _getStateReportId(self):
        return self._demographics.get('state_report_id', '')

    def _setStateReportId(self, id):
        if id is not None:
            id = unicode(id)
        self._setval('state_report_id', id)

    state_report_id = property(_getStateReportId, _setStateReportId)

    def _getGrade(self):
        return self._demographics.get('grade_class', '')

    def _setGrade(self, grade_class):
        if grade_class is not None:
            grade_class = unicode(grade_class)
        self._setval('grade_class', grade_class)

    grade_class = property(_getGrade, _setGrade)


class CanDoDemographicsInit(InitBase):

    after = ('schooltool.basicperson.demographics', )
    
    def __call__(self):
        dfs = IDemographicsFields(self.app)
        del dfs['ethnicity']
        dfs['state_report_id'] = TextFieldDescription('state_report_id',
                                                      'State report ID')
        dfs['ethnicity'] = EnumFieldDescription('ethnicity', 'Ethnicity')
        dfs['ethnicity'].items = [u'American Indian',
                                  u'Asian',
                                  u'Black',
                                  u'Hispanic',
                                  u'Unspecified',
                                  u'White']
        dfs['grade_class'] = TextFieldDescription('grade_class',
                                                  'Grade class')
        dfs['teacher_id'] = TextFieldDescription('teacher_id',
                                                 'Teacher ID')
