#
# CanDo - Web based competency tracking system.
# Copyright (C) 2006 Arlington Public Schools, Arlington, VA and The
# Shuttleworth Foundation.
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software Foundation,
# Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
#
"""
Level-related Tests

$Id$
"""
__docformat__='restructuredtext'

import unittest
from zope.component import provideAdapter
import zope.interface
from zope.testing import doctest, doctestunit
from zope.app.container import contained
from zope.app.testing import setup

from schooltool.requirement import requirement, interfaces, evaluation, testing
import schooltool.relationship.tests as relationship
from schooltool.app import app
from schooltool.app.interfaces import ISchoolToolApplication
from schooltool.testing.setup import setUpSchoolToolSite

from cando.tests import setUpGlobalComps

def setUp(test):
    setup.placefulSetUp()
    setup.setUpAnnotations()
    relationship.setUpRelationships()
    setUpSchoolToolSite()
    provideAdapter(app.getSchoolToolApplication,
                   (None,),
                   ISchoolToolApplication)
    provideAdapter(requirement.getRequirement,
                   (interfaces.IHaveRequirement,),
                   interfaces.IRequirement)
    provideAdapter(contained.NameChooser,
                   (zope.interface.Interface,))
    testing.setUpEvaluation()
    provideAdapter(evaluation.getEvaluations,
                   (interfaces.IHaveEvaluations,),
                   interfaces.IEvaluations)
    setUpGlobalComps()

def tearDown(test):
    setup.placefulTearDown()


def test_suite():
    return unittest.TestSuite((
        doctest.DocFileSuite('README.txt',
                             setUp=setUp, tearDown=tearDown,
                             globs={'pprint': doctestunit.pprint},
                             optionflags=doctest.NORMALIZE_WHITESPACE|
                                         doctest.REPORT_ONLY_FIRST_FAILURE|
                                         doctest.ELLIPSIS),
        ))


